LitModule
=========

.. currentmodule:: pykeen.contrib.lightning

.. autoclass:: LitModule
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LitModule.configure_optimizers
      ~LitModule.forward
      ~LitModule.on_before_zero_grad
      ~LitModule.train_dataloader
      ~LitModule.training_step
      ~LitModule.val_dataloader
      ~LitModule.validation_step

   .. rubric:: Methods Documentation

   .. automethod:: configure_optimizers
   .. automethod:: forward
   .. automethod:: on_before_zero_grad
   .. automethod:: train_dataloader
   .. automethod:: training_step
   .. automethod:: val_dataloader
   .. automethod:: validation_step
